@@ -3,16 +3,16 @@
 
 import time
 import board
-import busio
 import adafruit_mpu6050
 
-i2c = busio.I2C(board.SCL, board.SDA)
+i2c = board.I2C()  # uses board.SCL and board.SDA
+# i2c = board.STEMMA_I2C()  # For using the built-in STEMMA QT connector on a microcontroller
 mpu = adafruit_mpu6050.MPU6050(i2c)
 
 # This example is meant to be used with the serial plotter which makes
 # it easier to see how the readings change with different settings.
 # Make sure to poke and prod the sensor while the demo is running to
-# generate some intersting data!
+# generate some interesting data!
 
 while True:
     # first show some 'normal' readings
